@@ -5,7 +5,7 @@ _db_config = {
     'user': os.getenv('CPPACKAGE_DB_USER'),
     'password': os.getenv('CPPACKAGE_DB_PASSWORD'),
     'database': os.getenv('CPPACKAGE_DB_NAME'),
-    'port': int(os.getenv('CPPACKAGE_DB_PORT'), 3306),
+    'port': int(os.getenv('CPPACKAGE_DB_PORT', 3306)),
 }
 
 def set_db_config(host=None, user=None, password=None, database=None, port=None):
